# GetStockInfo Package

This package include a class to get stock info form web APIs. Current implementation include
	1. Tencent API
	2. Sina API (Deprecaited on Jan. 21st, 2022), need to new implemenation future
	3. 163 API (future implementation)